@@ -6,7 +6,6 @@
 ##############################################################################
 # Documentation
 ##############################################################################
-
 """
 Export a coloured, named prompt to ~/.bash_profile on container creation.
 """
@@ -41,6 +40,10 @@ class NamedPrompt(groot_rocker.extensions.RockerExtension):
     def validate_environment(self, unused_cli_args: typing.Dict[str, str]):
         pass
 
+    @staticmethod
+    def desired_extensions():
+        return {"user"}
+
     def get_preamble(self, unused_cli_args: typing.Dict[str, str]) -> str:
         return ''
 
@@ -50,14 +53,18 @@ class NamedPrompt(groot_rocker.extensions.RockerExtension):
             'templates/named_prompt.Dockerfile.em'
         ).decode('utf-8')
         substitutions = {}
-        userinfo = pwd.getpwuid(os.getuid())
-        substitutions['user_name'] = getattr(userinfo, 'pw_' + 'name')
+        if 'user' in cli_args and cli_args['user']:
+            userinfo = pwd.getpwuid(os.getuid())
+            substitutions['user_name'] = getattr(userinfo, 'pw_' + 'name')
+            substitutions['home_dir'] = f"/home/{substitutions['user_name']}"
+        else:
+            substitutions['user_name'] = "root"
+            substitutions['home_dir'] = "/root"
         if 'container_name' in cli_args and cli_args['container_name']:
             substitutions['container_name'] = cli_args['container_name']
         else:
             substitutions['container_name'] = r'\h'
-        dockerfile = em.expand(snippet, substitutions)
-        return dockerfile
+        return em.expand(snippet, substitutions)
 
     def get_docker_args(self, unused_cli_args: typing.Dict[str, str]) -> str:
         return ""
